@@ -1,13 +1,13 @@
 # PMAW
-# Copyright 2022 Matthew Podolak
+# Copyright 2023 Matthew Podolak
 # See LICENSE for details.
 
 """
 PMAW: Pushshift Multithread API Wrapper
 """
-__version__ = '2.1.3'
-__author__ = 'Matthew Podolak'
-__license__ = 'MIT'
+__version__ = "3.0.0"
+__author__ = "Matthew Podolak"
+__license__ = "MIT"
 
 from .RateLimit import RateLimit
 from .Request import Request
@@ -15,3 +15,4 @@ from .Response import Response
 from .Cache import Cache
 from .PushshiftAPIBase import PushshiftAPIBase
 from .PushshiftAPI import PushshiftAPI
+from .Metadata import Metadata
